searchNodes=[{"doc":"LiveProps is a library for managing properties and state within Phoenix LiveViews and Phoenix LiveComponents.FeaturesDeclaratively define props and state, initialize default values, and compute derived values using the LiveProps.prop/3 and LiveProps.state/3 macros.Supports required propsSupports asynchronous loading of state.Supports automatic re-computation of computed props and stateProps automatically added to module documentation.ExampleInside a LiveView or LiveComponent, you must use LiveProps.LiveView or LiveProps.LiveComponent, respectively. LiveComponents can have state and props, while a LiveView can only have state, so we'll look at an example LiveComponent to demonstrate both.defmodule MyAppWeb.ThermostatComponent do # If you generated an app with mix phx.new --live, # the line below would be: use MyAppWeb, :live_component use Phoenix.LiveComponent use LiveProps.LiveComponent prop :user_id, :integer, required: true prop :temperature, :float, compute: :get_temperature state :mode, :atom, default: :verbose def render(assigns) do ~L&quot;&quot;&quot; &lt;%= case @mode do %&gt; &lt;% :verbose -&gt; %&gt; Current temperature: &lt;%= @temperature %&gt; &lt;% _ -&gt; %&gt; &lt;%= @temperature %&gt; &lt;% end %&gt; &lt;button phx-click=&quot;toggle-mode&quot; phx-target=&quot;&lt;%= @myself %&gt;&quot;&gt;Toggle mode&lt;/button&gt; &quot;&quot;&quot; end def get_temperature(%{assigns: assigns} = _socket) do Thermostat.get_user_reading(assigns.user_id) end def handle_event(&quot;toggle-mode&quot;, _, socket) do new_mode = if socket.assigns.mode == :verbose, do: :compact, else: :verbose {:noreply, assign(socket, :mode, new_mode)} end endOur component requires a :user_id prop, which it uses to fetch the temperature. Since it is required, an error will be raised if you forget to pass it in.We also have the :temperature prop, which is a computed prop. This will be re-calculated automatically anytime the :user_id prop changes. It is calculated by get_temperature/1 which takes the socket as an argument and returns the value to be assigned. Calculations are run in the order defined so we could add even more computed props which depend on the temperature assign.Lastly, the component has a state called :mode which controls the display. We've given it a default value, which is assigned on mount. We could also add computed states which depends on other states.Notice what our component does not have: a Phoenix.LiveComponent.mount/1 or Phoenix.LiveComponent.update/2 callback. LiveProps handles that for you, by injecting lightweight mount/1 and update/2 callbacks under the hood. In pseudocode, these callbacks look like the following:def mount(socket) do {:ok, assign_default_states(socket)} end def update(assigns, socket) do raise_if_missing_required_props!(assigns) {:ok, assign_props_and_computed_props(socket)} endWhile LiveProps defines mount and update callbacks for you. You can still define your own and everything will continue to work. In a LiveComponent, any mount or update callbacks you define will be run after the the LiveProps callbacks (i.e. defaults and computed values will already be assigned to the socket)This module is not intended to be used directly but rather by means of LiveProps.LiveView and LiveProps.LiveComponent. Please see docs for those modules for additional information.","ref":"LiveProps.html","title":"LiveProps","type":"module"},{"doc":"","ref":"LiveProps.html#assign_states/2","title":"LiveProps.assign_states/2","type":"macro"},{"doc":"Define a property with the given name and type. Returns :okThis macro is meant to be called within a LiveComponent only. Types can be any atom and are just for documentation purposes.Options::default - A default value to assign to the prop.:required - boolean. If true, an error will be raised if the prop is not passed to the component.:compute - 1-arity function that takes the socket as an argument and returns the value to be assigned. Can be an atom of the name of a function in your component or a remote function call like &amp;MyModule.compute/1","ref":"LiveProps.html#prop/3","title":"LiveProps.prop/3","type":"macro"},{"doc":"","ref":"LiveProps.html#send_state/3","title":"LiveProps.send_state/3","type":"function"},{"doc":"","ref":"LiveProps.html#set_state/2","title":"LiveProps.set_state/2","type":"macro"},{"doc":"","ref":"LiveProps.html#set_state/3","title":"LiveProps.set_state/3","type":"macro"},{"doc":"Define state of given name and type. Returns :ok.Types can be any atom and are just for documentation purposes.","ref":"LiveProps.html#state/3","title":"LiveProps.state/3","type":"macro"},{"doc":"","ref":"LiveProps.LiveComponent.html","title":"LiveProps.LiveComponent","type":"module"},{"doc":"Use this module inside a Phoenix.LiveView to add state management functionality to your LiveViewsLiveView Lifecycle with LivePropsLiveProps injects lightweight Phoenix.LiveView.mount/3 and Phoenix.LiveView.handle_info/2 callbacks to help manage state.The lifecycle of the injected mount statement looks like this:assign_default_states(socket) -&gt; user_defined_mount(socket) -&gt; # if any assign_computed_states(socket)This reason we assign computed states last is because they may depend on data from params or session. LiveProps does not handle params and session so you will need to manually assign them in your own mount callback, if needed.Example defmodule ThermostatLive do # If you generated an app with mix phx.new --live, # the line below would be: use MyAppWeb, :live_view use Phoenix.LiveView use LiveProps.LiveView","ref":"LiveProps.LiveView.html","title":"LiveProps.LiveView","type":"module"}]